use sqlx::{query, PgPool};

use super::Result;

#[derive(Debug, Clone)]
pub struct Clothing {
    pub id: i32,
    pub name: String,
}

impl Clothing {
    pub async fn create(pool: &PgPool, name: &str) -> Result<()> {
        query!("INSERT INTO clothing (name) VALUES ($1);", name)
            .execute(pool)
            .await?;

        Ok(())
    }

    pub async fn read_all(pool: &PgPool) -> Result<Vec<Clothing>> {
        let records = query!("SELECT * FROM clothing;").fetch_all(pool).await?;

        let clothing_options = records
            .into_iter()
            .map(|v| Clothing {
                id: v.id,
                name: v.name,
            })
            .collect();

        Ok(clothing_options)
    }

    pub async fn read(pool: &PgPool, id: i32) -> Result<Option<Clothing>> {
        let record = query!("SELECT * FROM clothing WHERE id = $1;", id)
            .fetch_optional(pool)
            .await?;

        let vehicle = record.map(|v| Clothing {
            id: v.id,
            name: v.name,
        });

        Ok(vehicle)
    }

    pub async fn update(pool: &PgPool, id: i32, name: &str) -> Result<()> {
        query!("UPDATE clothing SET name = $1 WHERE id = $2;", name, id)
            .execute(pool)
            .await?;

        Ok(())
    }

    pub async fn delete(pool: &PgPool, id: i32) -> Result<()> {
        query!("DELETE FROM clothing WHERE id = $1;", id)
            .execute(pool)
            .await?;

        Ok(())
    }
}
